**Introduction**

A simple one-module training package providing functions to create and print F1 race (Q1 of Monaco 2018) report.

**Features**
- You can use command line interface in a usual Python way:

\>>> python report.py [-h] [--files FILES] [--driver DRIVER] [--desc | --asc]

- Or you can simply *import* function(s) to your project
